/* Modernizr 2.7.1 (Custom Build) | MIT & BSD
 * Build: http://modernizr.com/download/#-fontface-backgroundsize-borderimage-borderradius-boxshadow-flexbox-flexboxlegacy-hsla-multiplebgs-opacity-rgba-textshadow-cssanimations-csscolumns-generatedcontent-cssgradients-cssreflections-csstransforms-csstransforms3d-csstransitions-applicationcache-canvas-canvastext-draganddrop-hashchange-history-audio-video-indexeddb-input-inputtypes-localstorage-postmessage-sessionstorage-websockets-websqldatabase-webworkers-geolocation-inlinesvg-smil-svg-svgclippaths-touch-webgl-printshiv-mq-cssclasses-prefixed-teststyles-testprop-testallprops-hasevent-prefixes-domprefixes-a_download-audio_audiodata_api-audio_webaudio_api-battery_api-battery_level-blob_constructor-canvas_todataurl_type-contenteditable-contentsecuritypolicy-contextmenu-cookies-cors-css_backgroundposition_shorthand-css_backgroundposition_xy-css_backgroundrepeat-css_backgroundsizecover-css_boxsizing-css_calc-css_cubicbezierrange-css_displayrunin-css_displaytable-css_filters-css_lastchild-css_mask-css_mediaqueries-css_objectfit-css_overflow_scrolling-css_pointerevents-css_positionsticky-css_remunit-css_regions-css_resize-css_scrollbars-css_subpixelfont-css_supports-css_userselect-css_vhunit-css_vmaxunit-css_vminunit-css_vwunit-custom_protocol_handler-dataview_api-dom_classlist-dom_createElement_attrs-dom_dataset-dom_microdata-elem_datalist-elem_details-elem_output-elem_progress_meter-elem_ruby-elem_time-elem_track-emoji-es5_strictmode-event_deviceorientation_motion-exif_orientation-file_api-forms_formattribute-file_filesystem-forms_placeholder-forms_speechinput-forms_validation-fullscreen_api-gamepad-getusermedia-ie8compat-iframe_sandbox-iframe_seamless-iframe_srcdoc-img_apng-img_webp-json-lists_reversed-network_connection-network_eventsource-network_xhr2-notification-performance-pointerlock_api-quota_management_api-requestanimationframe-script_async-script_defer-style_scoped-svg_filters-unicode-url_data_uri-userdata-vibration-web_intents-webgl_extensions-window_framed-workers_blobworkers-workers_dataworkers-workers_sharedworkers-load
 */
;
window.Modernizr = function(a, b, c) {
    function D(a) {
        j.cssText = a
    }

    function E(a, b) {
        return D(n.join(a + ";") + (b || ""))
    }

    function F(a, b) {
        return typeof a === b
    }

    function G(a, b) {
        return!!~("" + a).indexOf(b)
    }

    function H(a, b) {
        for(var d in a
            ) {
            var e = a[d];
            if(!G(e, "-") && j[e] !== c) {
                return b == "pfx" ? e : !0
            }
        }
        return!1
    }

    function I(a, b, d) {
        for(var e in a
            ) {
            var f = b[a[e]];
            if(f !== c) {
                return d === !1 ? a[e] : F(f, "function") ? f.bind(d || b) : f
            }
        }
        return!1
    }

    function J(a, b, c) {
        var d = a.charAt(0).toUpperCase() + a.slice(1), e = (a + " " + p.join(d + " ") + d).split(" ");
        return F(b, "string") || F(b, "undefined") ? H(e,
                                                       b) : (e = (a + " " + q.join(d + " ") + d).split(" "), I(e,
                                                                                                               b,
                                                                                                               c))
    }

    function K() {
        e.input = function(c) {
            for(var d = 0, e = c.length; d < e; d++
                ) {
                u[c[d]] = c[d]in k;
            }
            return u.list && (u.list = !!b.createElement("datalist") && !!a.HTMLDataListElement), u
        }("autocomplete autofocus list placeholder max min multiple pattern required step".split(" ")), e.inputtypes = function(a) {
            for(var d = 0, e, f, h, i = a.length; d < i; d++
                ) {
                k.setAttribute("type",
                               f = a[d]), e = k.type !== "text", e && (k.value = l, k.style.cssText = "position:absolute;visibility:hidden;", /^range$/.test(f) && k.style.WebkitAppearance !== c ? (g.appendChild(k), h = b.defaultView, e = h.getComputedStyle && h.getComputedStyle(k,
                                                                                                                                                                                                                                                                                       null).WebkitAppearance !== "textfield" && k.offsetHeight !== 0, g.removeChild(k)) : /^(search|tel)$/.test(f) || (/^(url|email)$/.test(f) ? e = k.checkValidity && k.checkValidity() === !1 : e = k.value != l)), t[a[d]] = !!e;
            }
            return t
        }("search tel url email datetime date month week time datetime-local number range color".split(" "))
    }

    var d = "2.7.1", e = {}, f = !0, g = b.documentElement, h = "modernizr", i = b.createElement(h), j = i.style, k = b.createElement("input"), l = ":)", m = {}.toString, n = " -webkit- -moz- -o- -ms- ".split(" "), o = "Webkit Moz O ms", p = o.split(" "), q = o.toLowerCase().split(" "), r = {svg : "http://www.w3.org/2000/svg"}, s = {}, t = {}, u = {}, v = [], w = v.slice, x, y = function(a, c, d, e) {
        var f, i, j, k, l = b.createElement("div"), m = b.body, n = m || b.createElement("body");
        if(parseInt(d, 10)) {
            while(d--)j = b.createElement("div"), j.id = e ? e[d] : h + (d + 1), l.appendChild(j);
        }
        return f = ["&#173;", '<style id="s', h, '">', a, "</style>"].join(""), l.id = h, (m ? l : n).innerHTML += f, n.appendChild(l), m || (n.style.background = "", n.style.overflow = "hidden", k = g.style.overflow, g.style.overflow = "hidden", g.appendChild(n)), i = c(l,
                                                                                                                                                                                                                                                                                a), m ? l.parentNode.removeChild(l) : (n.parentNode.removeChild(n), g.style.overflow = k), !!i
    }, z = function(b) {
        var c = a.matchMedia || a.msMatchMedia;
        if(c) {
            return c(b).matches;
        }
        var d;
        return y("@media " + b + " { #" + h + " { position: absolute; } }",
                 function(b) {
                     d = (a.getComputedStyle ? getComputedStyle(b,
                                                                null) : b.currentStyle)["position"] == "absolute"
                 }), d
    }, A = function() {
        function d(d, e) {
            e = e || b.createElement(a[d] || "div"), d = "on" + d;
            var f = d in e;
            return f || (e.setAttribute || (e = b.createElement("div")), e.setAttribute && e.removeAttribute && (e.setAttribute(d,
                                                                                                                                ""), f = F(e[d],
                                                                                                                                           "function"), F(e[d],
                                                                                                                                                          "undefined") || (e[d] = c), e.removeAttribute(d))), e = null, f
        }

        var a = {select : "input", change : "input", submit : "form", reset : "form", error : "img", load : "img", abort : "img"};
        return d
    }(), B = {}.hasOwnProperty, C;
    !F(B, "undefined") && !F(B.call, "undefined") ? C = function(a, b) {
        return B.call(a, b)
    } : C = function(a, b) {
        return b in a && F(a.constructor.prototype[b], "undefined")
    }, Function.prototype.bind || (Function.prototype.bind = function(b) {
        var c = this;
        if(typeof c != "function") {
            throw new TypeError;
        }
        var d = w.call(arguments, 1), e = function() {
            if(this instanceof e) {
                var a = function() {
                };
                a.prototype = c.prototype;
                var f = new a, g = c.apply(f, d.concat(w.call(arguments)));
                return Object(g) === g ? g : f
            }
            return c.apply(b, d.concat(w.call(arguments)))
        };
        return e
    }), s.flexbox = function() {
        return J("flexWrap")
    }, s.flexboxlegacy = function() {
        return J("boxDirection")
    }, s.canvas = function() {
        var a = b.createElement("canvas");
        return!!a.getContext && !!a.getContext("2d")
    }, s.canvastext = function() {
        return!!e.canvas && !!F(b.createElement("canvas").getContext("2d").fillText,
                                "function")
    }, s.webgl = function() {
        return!!a.WebGLRenderingContext
    }, s.touch = function() {
        var c;
        return"ontouchstart"in a || a.DocumentTouch && b instanceof DocumentTouch ? c = !0 : y(["@media (", n.join("touch-enabled),("), h, ")", "{#modernizr{top:9px;position:absolute}}"].join(""),
                                                                                               function(a) {
                                                                                                   c = a.offsetTop === 9
                                                                                               }), c
    }, s.geolocation = function() {
        return"geolocation"in navigator
    }, s.postmessage = function() {
        return!!a.postMessage
    }, s.websqldatabase = function() {
        return!!a.openDatabase
    }, s.indexedDB = function() {
        return!!J("indexedDB", a)
    }, s.hashchange = function() {
        return A("hashchange",
                 a) && (b.documentMode === c || b.documentMode > 7)
    }, s.history = function() {
        return!!a.history && !!history.pushState
    }, s.draganddrop = function() {
        var a = b.createElement("div");
        return"draggable"in a || "ondragstart"in a && "ondrop"in a
    }, s.websockets = function() {
        return"WebSocket"in a || "MozWebSocket"in a
    }, s.rgba = function() {
        return D("background-color:rgba(150,255,150,.5)"), G(j.backgroundColor,
                                                             "rgba")
    }, s.hsla = function() {
        return D("background-color:hsla(120,40%,100%,.5)"), G(j.backgroundColor,
                                                              "rgba") || G(j.backgroundColor,
                                                                           "hsla")
    }, s.multiplebgs = function() {
        return D("background:url(https://),url(https://),red url(https://)"), /(url\s*\(.*?){3}/.test(j.background)
    }, s.backgroundsize = function() {
        return J("backgroundSize")
    }, s.borderimage = function() {
        return J("borderImage")
    }, s.borderradius = function() {
        return J("borderRadius")
    }, s.boxshadow = function() {
        return J("boxShadow")
    }, s.textshadow = function() {
        return b.createElement("div").style.textShadow === ""
    }, s.opacity = function() {
        return E("opacity:.55"), /^0.55$/.test(j.opacity)
    }, s.cssanimations = function() {
        return J("animationName")
    }, s.csscolumns = function() {
        return J("columnCount")
    }, s.cssgradients = function() {
        var a = "background-image:", b = "gradient(linear,left top,right bottom,from(#9f9),to(white));", c = "linear-gradient(left top,#9f9, white);";
        return D((a + "-webkit- ".split(" ").join(b + a) + n.join(c + a)).slice(0,
                                                                                -a.length)), G(j.backgroundImage,
                                                                                               "gradient")
    }, s.cssreflections = function() {
        return J("boxReflect")
    }, s.csstransforms = function() {
        return!!J("transform")
    }, s.csstransforms3d = function() {
        var a = !!J("perspective");
        return a && "webkitPerspective"in g.style && y("@media (transform-3d),(-webkit-transform-3d){#modernizr{left:9px;position:absolute;height:3px;}}",
                                                       function(b, c) {
                                                           a = b.offsetLeft === 9 && b.offsetHeight === 3
                                                       }), a
    }, s.csstransitions = function() {
        return J("transition")
    }, s.fontface = function() {
        var a;
        return y('@font-face {font-family:"font";src:url("https://")}',
                 function(c, d) {
                     var e = b.getElementById("smodernizr"), f = e.sheet || e.styleSheet, g = f ? f.cssRules && f.cssRules[0] ? f.cssRules[0].cssText : f.cssText || "" : "";
                     a = /src/i.test(g) && g.indexOf(d.split(" ")[0]) === 0
                 }), a
    }, s.generatedcontent = function() {
        var a;
        return y(["#", h, "{font:0/0 a}#", h, ':after{content:"', l, '";visibility:hidden;font:3px/1 a}'].join(""),
                 function(b) {
                     a = b.offsetHeight >= 3
                 }), a
    }, s.video = function() {
        var a = b.createElement("video"), c = !1;
        try {
            if(c = !!a.canPlayType) {
                c = new Boolean(c), c.ogg = a.canPlayType('video/ogg; codecs="theora"').replace(/^no$/,
                                                                                                ""), c.h264 = a.canPlayType('video/mp4; codecs="avc1.42E01E"').replace(/^no$/,
                                                                                                                                                                       ""), c.webm = a.canPlayType('video/webm; codecs="vp8, vorbis"').replace(/^no$/,
                                                                                                                                                                                                                                               "")
            }
        }
        catch(d) {
        }
        return c
    }, s.audio = function() {
        var a = b.createElement("audio"), c = !1;
        try {
            if(c = !!a.canPlayType) {
                c = new Boolean(c), c.ogg = a.canPlayType('audio/ogg; codecs="vorbis"').replace(/^no$/,
                                                                                                ""), c.mp3 = a.canPlayType("audio/mpeg;").replace(/^no$/,
                                                                                                                                                  ""), c.wav = a.canPlayType('audio/wav; codecs="1"').replace(/^no$/,
                                                                                                                                                                                                              ""), c.m4a = (a.canPlayType("audio/x-m4a;") || a.canPlayType("audio/aac;")).replace(/^no$/,
                                                                                                                                                                                                                                                                                                  "")
            }
        }
        catch(d) {
        }
        return c
    }, s.localstorage = function() {
        try {
            return localStorage.setItem(h, h), localStorage.removeItem(h), !0
        }
        catch(a) {
            return!1
        }
    }, s.sessionstorage = function() {
        try {
            return sessionStorage.setItem(h,
                                          h), sessionStorage.removeItem(h), !0
        }
        catch(a) {
            return!1
        }
    }, s.webworkers = function() {
        return!!a.Worker
    }, s.applicationcache = function() {
        return!!a.applicationCache
    }, s.svg = function() {
        return!!b.createElementNS && !!b.createElementNS(r.svg,
                                                         "svg").createSVGRect
    }, s.inlinesvg = function() {
        var a = b.createElement("div");
        return a.innerHTML = "<svg/>", (a.firstChild && a.firstChild.namespaceURI) == r.svg
    }, s.smil = function() {
        return!!b.createElementNS && /SVGAnimate/.test(m.call(b.createElementNS(r.svg,
                                                                                "animate")))
    }, s.svgclippaths = function() {
        return!!b.createElementNS && /SVGClipPath/.test(m.call(b.createElementNS(r.svg,
                                                                                 "clipPath")))
    };
    for(var L in s
        ) {
        C(s,
          L) && (x = L.toLowerCase(), e[x] = s[L](), v.push((e[x] ? "" : "no-") + x));
    }
    return e.input || K(), e.addTest = function(a, b) {
        if(typeof a == "object") {
            for(var d in a
                ) {
                C(a, d) && e.addTest(d, a[d]);
            }
        }
        else {
            a = a.toLowerCase();
            if(e[a] !== c) {
                return e;
            }
            b = typeof b == "function" ? b() : b, typeof f != "undefined" && f && (g.className += " " + (b ? "" : "no-") + a), e[a] = b
        }
        return e
    }, D(""), i = k = null, e._version = d, e._prefixes = n, e._domPrefixes = q, e._cssomPrefixes = p, e.mq = z, e.hasEvent = A, e.testProp = function(a) {
        return H([a])
    }, e.testAllProps = J, e.testStyles = y, e.prefixed = function(a, b, c) {
        return b ? J(a, b, c) : J(a, "pfx")
    }, g.className = g.className.replace(/(^|\s)no-js(\s|$)/,
                                         "$1$2") + (f ? " js " + v.join(" ") : ""), e
}(this, this.document), function(a, b) {
    function l(a, b) {
        var c = a.createElement("p"), d = a.getElementsByTagName("head")[0] || a.documentElement;
        return c.innerHTML = "x<style>" + b + "</style>", d.insertBefore(c.lastChild,
                                                                         d.firstChild)
    }

    function m() {
        var a = s.elements;
        return typeof a == "string" ? a.split(" ") : a
    }

    function n(a) {
        var b = j[a[h]];
        return b || (b = {}, i++, a[h] = i, j[i] = b), b
    }

    function o(a, c, d) {
        c || (c = b);
        if(k) {
            return c.createElement(a);
        }
        d || (d = n(c));
        var g;
        return d.cache[a] ? g = d.cache[a].cloneNode() : f.test(a) ? g = (d.cache[a] = d.createElem(a)).cloneNode() : g = d.createElem(a), g.canHaveChildren && !e.test(a) && !g.tagUrn ? d.frag.appendChild(g) : g
    }

    function p(a, c) {
        a || (a = b);
        if(k) {
            return a.createDocumentFragment();
        }
        c = c || n(a);
        var d = c.frag.cloneNode(), e = 0, f = m(), g = f.length;
        for(; e < g; e++
            ) {
            d.createElement(f[e]);
        }
        return d
    }

    function q(a, b) {
        b.cache || (b.cache = {}, b.createElem = a.createElement, b.createFrag = a.createDocumentFragment, b.frag = b.createFrag()), a.createElement = function(c) {
            return s.shivMethods ? o(c, a, b) : b.createElem(c)
        }, a.createDocumentFragment = Function("h,f",
                                               "return function(){var n=f.cloneNode(),c=n.createElement;h.shivMethods&&(" + m().join().replace(/\w+/g,
                                                                                                                                               function(a) {
                                                                                                                                                   return b.createElem(a), b.frag.createElement(a), 'c("' + a + '")'
                                                                                                                                               }) + ");return n}")(s,
                                                                                                                                                                   b.frag)
    }

    function r(a) {
        a || (a = b);
        var c = n(a);
        return s.shivCSS && !g && !c.hasCSS && (c.hasCSS = !!l(a,
                                                               "article,aside,dialog,figcaption,figure,footer,header,hgroup,main,nav,section{display:block}mark{background:#FF0;color:#000}template{display:none}")), k || q(a,
                                                                                                                                                                                                                             c), a
    }

    function w(a) {
        var b, c = a.getElementsByTagName("*"), d = c.length, e = RegExp("^(?:" + m().join("|") + ")$",
                                                                         "i"), f = [];
        while(d--)b = c[d], e.test(b.nodeName) && f.push(b.applyElement(x(b)));
        return f
    }

    function x(a) {
        var b, c = a.attributes, d = c.length, e = a.ownerDocument.createElement(u + ":" + a.nodeName);
        while(d--)b = c[d], b.specified && e.setAttribute(b.nodeName,
                                                          b.nodeValue);
        return e.style.cssText = a.style.cssText, e
    }

    function y(a) {
        var b, c = a.split("{"), d = c.length, e = RegExp("(^|[\\s,>+~])(" + m().join("|") + ")(?=[[\\s,>+~#.:]|$)",
                                                          "gi"), f = "$1" + u + "\\:$2";
        while(d--)b = c[d] = c[d].split("}"), b[b.length - 1] = b[b.length - 1].replace(e,
                                                                                        f), c[d] = b.join("}");
        return c.join("{")
    }

    function z(a) {
        var b = a.length;
        while(b--)a[b].removeNode()
    }

    function A(a) {
        function g() {
            clearTimeout(d._removeSheetTimer), b && b.removeNode(!0), b = null
        }

        var b, c, d = n(a), e = a.namespaces, f = a.parentWindow;
        return!v || a.printShived ? a : (typeof e[u] == "undefined" && e.add(u), f.attachEvent("onbeforeprint",
                                                                                               function() {
                                                                                                   g();
                                                                                                   var d, e, f, h = a.styleSheets, i = [], j = h.length, k = Array(j);
                                                                                                   while(j--)k[j] = h[j];
                                                                                                   while(f = k.pop())if(!f.disabled && t.test(f.media)) {
                                                                                                       try {
                                                                                                           d = f.imports, e = d.length
                                                                                                       }
                                                                                                       catch(m) {
                                                                                                           e = 0
                                                                                                       }
                                                                                                       for(j = 0;
                                                                                                           j < e;
                                                                                                           j++
                                                                                                           ) {
                                                                                                           k.push(d[j]);
                                                                                                       }
                                                                                                       try {
                                                                                                           i.push(f.cssText)
                                                                                                       }
                                                                                                       catch(m) {
                                                                                                       }
                                                                                                   }
                                                                                                   i = y(i.reverse().join("")), c = w(a), b = l(a,
                                                                                                                                                i)
                                                                                               }), f.attachEvent("onafterprint",
                                                                                                                 function() {
                                                                                                                     z(c), clearTimeout(d._removeSheetTimer), d._removeSheetTimer = setTimeout(g,
                                                                                                                                                                                               500)
                                                                                                                 }), a.printShived = !0, a)
    }

    var c = "3.7.0", d = a.html5 || {}, e = /^<|^(?:button|map|select|textarea|object|iframe|option|optgroup)$/i, f = /^(?:a|b|code|div|fieldset|h1|h2|h3|h4|h5|h6|i|label|li|ol|p|q|span|strong|style|table|tbody|td|th|tr|ul)$/i, g, h = "_html5shiv", i = 0, j = {}, k;
    (function() {
        try {
            var a = b.createElement("a");
            a.innerHTML = "<xyz></xyz>", g = "hidden"in a, k = a.childNodes.length == 1 || function() {
                b.createElement("a");
                var a = b.createDocumentFragment();
                return typeof a.cloneNode == "undefined" || typeof a.createDocumentFragment == "undefined" || typeof a.createElement == "undefined"
            }()
        }
        catch(c) {
            g = !0, k = !0
        }
    })();
    var s = {elements : d.elements || "abbr article aside audio bdi canvas data datalist details dialog figcaption figure footer header hgroup main mark meter nav output progress section summary template time video", version : c, shivCSS : d.shivCSS !== !1, supportsUnknownElements : k, shivMethods : d.shivMethods !== !1, type : "default", shivDocument : r, createElement : o, createDocumentFragment : p};
    a.html5 = s, r(b);
    var t = /^$|\b(?:all|print)\b/, u = "html5shiv", v = !k && function() {
        var c = b.documentElement;
        return typeof b.namespaces != "undefined" && typeof b.parentWindow != "undefined" && typeof c.applyElement != "undefined" && typeof c.removeNode != "undefined" && typeof a.attachEvent != "undefined"
    }();
    s.type += " print", s.shivPrint = A, A(b)
}(this, document), function(a, b, c) {
    function d(a) {
        return"[object Function]" == o.call(a)
    }

    function e(a) {
        return"string" == typeof a
    }

    function f() {
    }

    function g(a) {
        return!a || "loaded" == a || "complete" == a || "uninitialized" == a
    }

    function h() {
        var a = p.shift();
        q = 1, a ? a.t ? m(function() {
            ("c" == a.t ? B.injectCss : B.injectJs)(a.s, 0, a.a, a.x, a.e, 1)
        }, 0) : (a(), h()) : q = 0
    }

    function i(a, c, d, e, f, i, j) {
        function k(b) {
            if(!o && g(l.readyState) && (u.r = o = 1, !q && h(), l.onload = l.onreadystatechange = null, b)) {
                "img" != a && m(function() {
                    t.removeChild(l)
                }, 50);
                for(var d in y[c]
                    ) {
                    y[c].hasOwnProperty(d) && y[c][d].onload()
                }
            }
        }

        var j = j || B.errorTimeout, l = b.createElement(a), o = 0, r = 0, u = {t : d, s : c, e : f, a : i, x : j};
        1 === y[c] && (r = 1, y[c] = []), "object" == a ? l.data = c : (l.src = c, l.type = a), l.width = l.height = "0", l.onerror = l.onload = l.onreadystatechange = function() {
            k.call(this, r)
        }, p.splice(e, 0,
                    u), "img" != a && (r || 2 === y[c] ? (t.insertBefore(l,
                                                                         s ? null : n), m(k,
                                                                                          j)) : y[c].push(l))
    }

    function j(a, b, c, d, f) {
        return q = 0, b = b || "j", e(a) ? i("c" == b ? v : u, a, b, this.i++,
                                             c, d, f) : (p.splice(this.i++, 0,
                                                                  a), 1 == p.length && h()), this
    }

    function k() {
        var a = B;
        return a.loader = {load : j, i : 0}, a
    }

    var l = b.documentElement, m = a.setTimeout, n = b.getElementsByTagName("script")[0], o = {}.toString, p = [], q = 0, r = "MozAppearance"in l.style, s = r && !!b.createRange().compareNode, t = s ? l : n.parentNode, l = a.opera && "[object Opera]" == o.call(a.opera), l = !!b.attachEvent && !l, u = r ? "object" : l ? "script" : "img", v = l ? "script" : u, w = Array.isArray || function(a) {
        return"[object Array]" == o.call(a)
    }, x = [], y = {}, z = {timeout : function(a, b) {
        return b.length && (a.timeout = b[0]), a
    }}, A, B;
    B = function(a) {
        function b(a) {
            var a = a.split("!"), b = x.length, c = a.pop(), d = a.length, c = {url : c, origUrl : c, prefixes : a}, e, f, g;
            for(f = 0; f < d; f++
                ) {
                g = a[f].split("="), (e = z[g.shift()]) && (c = e(c, g));
            }
            for(f = 0; f < b; f++
                ) {
                c = x[f](c);
            }
            return c
        }

        function g(a, e, f, g, h) {
            var i = b(a), j = i.autoCallback;
            i.url.split(".").pop().split("?").shift(), i.bypass || (e && (e = d(e) ? e : e[a] || e[g] || e[a.split("/").pop().split("?")[0]]), i.instead ? i.instead(a,
                                                                                                                                                                     e,
                                                                                                                                                                     f,
                                                                                                                                                                     g,
                                                                                                                                                                     h) : (y[i.url] ? i.noexec = !0 : y[i.url] = 1, f.load(i.url,
                                                                                                                                                                                                                           i.forceCSS || !i.forceJS && "css" == i.url.split(".").pop().split("?").shift() ? "c" : c,
                                                                                                                                                                                                                           i.noexec,
                                                                                                                                                                                                                           i.attrs,
                                                                                                                                                                                                                           i.timeout), (d(e) || d(j)) && f.load(function() {
                k(), e && e(i.origUrl, h, g), j && j(i.origUrl, h,
                                                     g), y[i.url] = 2
            })))
        }

        function h(a, b) {
            function c(a, c) {
                if(a) {
                    if(e(a)) {
                        c || (j = function() {
                            var a = [].slice.call(arguments);
                            k.apply(this, a), l()
                        }), g(a, j, b, 0, h);
                    }
                    else if(Object(a) === a) {
                        for(n in m = function() {
                            var b = 0, c;
                            for(c in a
                                ) {
                                a.hasOwnProperty(c) && b++;
                            }
                            return b
                        }(), a
                            ) {
                            a.hasOwnProperty(n) && (!c && !--m && (d(j) ? j = function() {
                                var a = [].slice.call(arguments);
                                k.apply(this, a), l()
                            } : j[n] = function(a) {
                                return function() {
                                    var b = [].slice.call(arguments);
                                    a && a.apply(this, b), l()
                                }
                            }(k[n])), g(a[n], j, b, n, h))
                        }
                    }
                }
                else {
                    !c && l()
                }
            }

            var h = !!a.test, i = a.load || a.both, j = a.callback || f, k = j, l = a.complete || f, m, n;
            c(h ? a.yep : a.nope, !!i), i && c(i)
        }

        var i, j, l = this.yepnope.loader;
        if(e(a)) {
            g(a, 0, l, 0);
        }
        else if(w(a)) {
            for(i = 0; i < a.length; i++
                ) {
                j = a[i], e(j) ? g(j, 0, l,
                                   0) : w(j) ? B(j) : Object(j) === j && h(j,
                                                                           l);
            }
        }
        else {
            Object(a) === a && h(a, l)
        }
    }, B.addPrefix = function(a, b) {
        z[a] = b
    }, B.addFilter = function(a) {
        x.push(a)
    }, B.errorTimeout = 1e4, null == b.readyState && b.addEventListener && (b.readyState = "loading", b.addEventListener("DOMContentLoaded",
                                                                                                                         A = function() {
                                                                                                                             b.removeEventListener("DOMContentLoaded",
                                                                                                                                                   A,
                                                                                                                                                   0), b.readyState = "complete"
                                                                                                                         },
                                                                                                                         0)), a.yepnope = k(), a.yepnope.executeStack = h, a.yepnope.injectJs = function(a, c, d, e, i, j) {
        var k = b.createElement("script"), l, o, e = e || B.errorTimeout;
        k.src = a;
        for(o in d
            ) {
            k.setAttribute(o, d[o]);
        }
        c = j ? h : c || f, k.onreadystatechange = k.onload = function() {
            !l && g(k.readyState) && (l = 1, c(), k.onload = k.onreadystatechange = null)
        }, m(function() {
            l || (l = 1, c(1))
        }, e), i ? k.onload() : n.parentNode.insertBefore(k, n)
    }, a.yepnope.injectCss = function(a, c, d, e, g, i) {
        var e = b.createElement("link"), j, c = i ? h : c || f;
        e.href = a, e.rel = "stylesheet", e.type = "text/css";
        for(j in d
            ) {
            e.setAttribute(j, d[j]);
        }
        g || (n.parentNode.insertBefore(e, n), m(c, 0))
    }
}(this, document), Modernizr.load = function() {
    yepnope.apply(window, [].slice.call(arguments, 0))
}, Modernizr.addTest("adownload",
                     "download"in document.createElement("a")), Modernizr.addTest("audiodata",
                                                                                  !!window.Audio), Modernizr.addTest("webaudio",
                                                                                                                     !!window.webkitAudioContext || !!window.AudioContext), Modernizr.addTest("lowbattery",
                                                                                                                                                                                              function() {
                                                                                                                                                                                                  var a = .2, b = Modernizr.prefixed("battery",
                                                                                                                                                                                                                                     navigator);
                                                                                                                                                                                                  return!!(b && !b.charging && b.level <= a)
                                                                                                                                                                                              }), Modernizr.addTest("battery",
                                                                                                                                                                                                                    !!Modernizr.prefixed("battery",
                                                                                                                                                                                                                                         navigator)), Modernizr.addTest("blobconstructor",
                                                                                                                                                                                                                                                                        function() {
                                                                                                                                                                                                                                                                            try {
                                                                                                                                                                                                                                                                                return!!(new Blob)
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                            catch(a) {
                                                                                                                                                                                                                                                                                return!1
                                                                                                                                                                                                                                                                            }
                                                                                                                                                                                                                                                                        }), function() {
    if(!Modernizr.canvas) {
        return!1;
    }
    var a = new Image, b = document.createElement("canvas"), c = b.getContext("2d");
    a.onload = function() {
        c.drawImage(a, 0, 0), Modernizr.addTest("todataurljpeg", function() {
            return b.toDataURL("image/jpeg").indexOf("data:image/jpeg") === 0
        }), Modernizr.addTest("todataurlwebp", function() {
            return b.toDataURL("image/webp").indexOf("data:image/webp") === 0
        })
    }, a.src = "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAACklEQVR4nGMAAQAABQABDQottAAAAABJRU5ErkJggg=="
}(), Modernizr.addTest("contentsecuritypolicy",
                       "securityPolicy"in document || "SecurityPolicy"in document), Modernizr.addTest("contenteditable",
                                                                                                      "contentEditable"in document.documentElement), Modernizr.addTest("contextmenu",
                                                                                                                                                                       "contextMenu"in document.documentElement && "HTMLMenuItemElement"in window), Modernizr.addTest("cookies",
                                                                                                                                                                                                                                                                      function() {
                                                                                                                                                                                                                                                                          if(navigator.cookieEnabled) {
                                                                                                                                                                                                                                                                              return!0;
                                                                                                                                                                                                                                                                          }
                                                                                                                                                                                                                                                                          document.cookie = "cookietest=1";
                                                                                                                                                                                                                                                                          var a = document.cookie.indexOf("cookietest=") != -1;
                                                                                                                                                                                                                                                                          return document.cookie = "cookietest=1; expires=Thu, 01-Jan-1970 00:00:01 GMT", a
                                                                                                                                                                                                                                                                      }), Modernizr.addTest("cors",
                                                                                                                                                                                                                                                                                            !!(window.XMLHttpRequest && "withCredentials"in new XMLHttpRequest)), function() {
    var a = document.createElement("a"), b = a.style, c = "right 10px bottom 10px";
    Modernizr.addTest("bgpositionshorthand", function() {
        return b.cssText = "background-position: " + c + ";", b.backgroundPosition === c
    })
}(), Modernizr.addTest("bgpositionxy", function() {
    return Modernizr.testStyles("#modernizr {background-position: 3px 5px;}",
                                function(a) {
                                    var b = window.getComputedStyle ? getComputedStyle(a,
                                                                                       null) : a.currentStyle, c = b.backgroundPositionX == "3px" || b["background-position-x"] == "3px", d = b.backgroundPositionY == "5px" || b["background-position-y"] == "5px";
                                    return c && d
                                })
}), function() {
    function a(a) {
        return window.getComputedStyle ? getComputedStyle(a,
                                                          null).getPropertyValue("background") : a.currentStyle.background
    }

    Modernizr.testStyles(" #modernizr { background-repeat: round; } ",
                         function(b, c) {
                             Modernizr.addTest("bgrepeatround", a(b) == "round")
                         }), Modernizr.testStyles(" #modernizr { background-repeat: space; } ",
                                                  function(b, c) {
                                                      Modernizr.addTest("bgrepeatspace",
                                                                        a(b) == "space")
                                                  })
}(), Modernizr.testStyles("#modernizr{background-size:cover}", function(a) {
    var b = window.getComputedStyle ? window.getComputedStyle(a,
                                                              null) : a.currentStyle;
    Modernizr.addTest("bgsizecover", b.backgroundSize == "cover")
}), Modernizr.addTest("boxsizing", function() {
    return Modernizr.testAllProps("boxSizing") && (document.documentMode === undefined || document.documentMode > 7)
}), Modernizr.addTest("csscalc", function() {
    var a = "width:", b = "calc(10px);", c = document.createElement("div");
    return c.style.cssText = a + Modernizr._prefixes.join(b + a), !!c.style.length
}), Modernizr.testStyles(" #modernizr { display: run-in; } ", function(a, b) {
    var c = window.getComputedStyle ? getComputedStyle(a,
                                                       null).getPropertyValue("display") : a.currentStyle.display;
    Modernizr.addTest("display-runin", c == "run-in")
}), Modernizr.addTest("cubicbezierrange", function() {
    var a = document.createElement("div");
    return a.style.cssText = Modernizr._prefixes.join("transition-timing-function:cubic-bezier(1,0,0,1.1); "), !!a.style.length
}), Modernizr.addTest("display-table", function() {
    var a = window.document, b = a.documentElement, c = a.createElement("div"), d = a.createElement("div"), e = a.createElement("div"), f;
    return c.style.cssText = "display: table", d.style.cssText = e.style.cssText = "display: table-cell; padding: 10px", c.appendChild(d), c.appendChild(e), b.insertBefore(c,
                                                                                                                                                                            b.firstChild), f = d.offsetLeft < e.offsetLeft, b.removeChild(c), f
}), Modernizr.addTest("cssfilters", function() {
    var a = document.createElement("div");
    return a.style.cssText = Modernizr._prefixes.join("filter:blur(2px); "), !!a.style.length && (document.documentMode === undefined || document.documentMode > 9)
}), Modernizr.addTest("lastchild", function() {
    return Modernizr.testStyles("#modernizr div {width:100px} #modernizr :last-child{width:200px;display:block}",
                                function(a) {
                                    return a.lastChild.offsetWidth > a.firstChild.offsetWidth
                                }, 2)
}), Modernizr.addTest("cssmask",
                      Modernizr.testAllProps("maskRepeat")), Modernizr.addTest("mediaqueries",
                                                                               Modernizr.mq("only all")), Modernizr.addTest("object-fit",
                                                                                                                            !!Modernizr.prefixed("objectFit")), Modernizr.addTest("overflowscrolling",
                                                                                                                                                                                  function() {
                                                                                                                                                                                      return Modernizr.testAllProps("overflowScrolling")
                                                                                                                                                                                  }), Modernizr.addTest("pointerevents",
                                                                                                                                                                                                        function() {
                                                                                                                                                                                                            var a = document.createElement("x"), b = document.documentElement, c = window.getComputedStyle, d;
                                                                                                                                                                                                            return"pointerEvents"in a.style ? (a.style.pointerEvents = "auto", a.style.pointerEvents = "x", b.appendChild(a), d = c && c(a,
                                                                                                                                                                                                                                                                                                                                         "").pointerEvents === "auto", b.removeChild(a), !!d) : !1
                                                                                                                                                                                                        }), Modernizr.addTest("csspositionsticky",
                                                                                                                                                                                                                              function() {
                                                                                                                                                                                                                                  var a = "position:", b = "sticky", c = document.createElement("modernizr"), d = c.style;
                                                                                                                                                                                                                                  return d.cssText = a + Modernizr._prefixes.join(b + ";" + a).slice(0,
                                                                                                                                                                                                                                                                                                     -a.length), d.position.indexOf(b) !== -1
                                                                                                                                                                                                                              }), Modernizr.addTest("cssremunit",
                                                                                                                                                                                                                                                    function() {
                                                                                                                                                                                                                                                        var a = document.createElement("div");
                                                                                                                                                                                                                                                        try {
                                                                                                                                                                                                                                                            a.style.fontSize = "3rem"
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                        catch(b) {
                                                                                                                                                                                                                                                        }
                                                                                                                                                                                                                                                        return/rem/.test(a.style.fontSize)
                                                                                                                                                                                                                                                    }), Modernizr.addTest("regions",
                                                                                                                                                                                                                                                                          function() {
                                                                                                                                                                                                                                                                              var a = Modernizr.prefixed("flowFrom"), b = Modernizr.prefixed("flowInto");
                                                                                                                                                                                                                                                                              if(!a || !b) {
                                                                                                                                                                                                                                                                                  return!1;
                                                                                                                                                                                                                                                                              }
                                                                                                                                                                                                                                                                              var c = document.createElement("div"), d = document.createElement("div"), e = document.createElement("div"), f = "modernizr_flow_for_regions_check";
                                                                                                                                                                                                                                                                              d.innerText = "M", c.style.cssText = "top: 150px; left: 150px; padding: 0px;", e.style.cssText = "width: 50px; height: 50px; padding: 42px;", e.style[a] = f, c.appendChild(d), c.appendChild(e), document.documentElement.appendChild(c);
                                                                                                                                                                                                                                                                              var g, h, i = d.getBoundingClientRect();
                                                                                                                                                                                                                                                                              return d.style[b] = f, g = d.getBoundingClientRect(), h = g.left - i.left, document.documentElement.removeChild(c), d = e = c = undefined, h == 42
                                                                                                                                                                                                                                                                          }), Modernizr.addTest("cssresize",
                                                                                                                                                                                                                                                                                                Modernizr.testAllProps("resize")), Modernizr.addTest("cssscrollbar",
                                                                                                                                                                                                                                                                                                                                                     function() {
                                                                                                                                                                                                                                                                                                                                                         var a, b = "#modernizr{overflow: scroll; width: 40px }#" + Modernizr._prefixes.join("scrollbar{width:0px} #modernizr::").split("#").slice(1).join("#") + "scrollbar{width:0px}";
                                                                                                                                                                                                                                                                                                                                                         return Modernizr.testStyles(b,
                                                                                                                                                                                                                                                                                                                                                                                     function(b) {
                                                                                                                                                                                                                                                                                                                                                                                         a = "scrollWidth"in b && b.scrollWidth == 40
                                                                                                                                                                                                                                                                                                                                                                                     }), a
                                                                                                                                                                                                                                                                                                                                                     }), Modernizr.addTest("subpixelfont",
                                                                                                                                                                                                                                                                                                                                                                           function() {
                                                                                                                                                                                                                                                                                                                                                                               var a, b = "#modernizr{position: absolute; top: -10em; visibility:hidden; font: normal 10px arial;}#subpixel{float: left; font-size: 33.3333%;}";
                                                                                                                                                                                                                                                                                                                                                                               return Modernizr.testStyles(b,
                                                                                                                                                                                                                                                                                                                                                                                                           function(b) {
                                                                                                                                                                                                                                                                                                                                                                                                               var c = b.firstChild;
                                                                                                                                                                                                                                                                                                                                                                                                               c.innerHTML = "This is a text written in Arial", a = window.getComputedStyle ? window.getComputedStyle(c,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      null).getPropertyValue("width") !== "44px" : !1
                                                                                                                                                                                                                                                                                                                                                                                                           },
                                                                                                                                                                                                                                                                                                                                                                                                           1,
                                                                                                                                                                                                                                                                                                                                                                                                           ["subpixel"]), a
                                                                                                                                                                                                                                                                                                                                                                           }), Modernizr.addTest("supports",
                                                                                                                                                                                                                                                                                                                                                                                                 "CSSSupportsRule"in window), Modernizr.addTest("userselect",
                                                                                                                                                                                                                                                                                                                                                                                                                                                function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                    return Modernizr.testAllProps("user-select")
                                                                                                                                                                                                                                                                                                                                                                                                                                                }), Modernizr.addTest("cssvhunit",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                      function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                          var a;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                          return Modernizr.testStyles("#modernizr { height: 50vh; }",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      function(b, c) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          var d = parseInt(window.innerHeight / 2,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           10), e = parseInt((window.getComputedStyle ? getComputedStyle(b,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         null) : b.currentStyle).height,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             10);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          a = e == d
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      }), a
                                                                                                                                                                                                                                                                                                                                                                                                                                                                      }), Modernizr.addTest("cssvmaxunit",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                var a;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                return Modernizr.testStyles("#modernizr { width: 50vmax; }",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            function(b, c) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                var d = window.innerWidth / 100, e = window.innerHeight / 100, f = parseInt((window.getComputedStyle ? getComputedStyle(b,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        null) : b.currentStyle).width,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            10);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                a = parseInt(Math.max(d,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      e) * 50,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             10) == f
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            }), a
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            }), Modernizr.addTest("cssvminunit",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      var a;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      return Modernizr.testStyles("#modernizr { width: 50vmin; }",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  function(b, c) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      var d = window.innerWidth / 100, e = window.innerHeight / 100, f = parseInt((window.getComputedStyle ? getComputedStyle(b,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              null) : b.currentStyle).width,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  10);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      a = parseInt(Math.min(d,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            e) * 50,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   10) == f
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  }), a
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  }), Modernizr.addTest("cssvwunit",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            var a;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            return Modernizr.testStyles("#modernizr { width: 50vw; }",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        function(b, c) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            var d = parseInt(window.innerWidth / 2,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             10), e = parseInt((window.getComputedStyle ? getComputedStyle(b,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           null) : b.currentStyle).width,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               10);
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            a = e == d
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        }), a
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        }), Modernizr.addTest("customprotocolhandler",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  return!!navigator.registerProtocolHandler
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              }), Modernizr.addTest("dataview",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    typeof DataView != "undefined" && "getFloat64"in DataView.prototype), Modernizr.addTest("classlist",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            "classList"in document.documentElement), Modernizr.addTest("dataset",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           var a = document.createElement("div");
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           return a.setAttribute("data-a-b",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 "c"), !!a.dataset && a.dataset.aB === "c"
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       }), Modernizr.addTest("createelement-attrs",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 try {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     return document.createElement("<input name='test' />").getAttribute("name") == "test"
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 catch(a) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     return!1
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             }), Modernizr.addTest("microdata",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   !!document.getItems), Modernizr.addTest("datalistelem",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           Modernizr.input.list), Modernizr.addTest("details",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        var a = document, b = a.createElement("details"), c, d, e;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        return"open"in b ? (d = a.body || function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            var b = a.documentElement;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            return c = !0, b.insertBefore(a.createElement("body"),
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          b.firstElementChild || b.firstChild)
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        }(), b.innerHTML = "<summary>a</summary>b", b.style.display = "block", d.appendChild(b), e = b.offsetHeight, b.open = !0, e = e != b.offsetHeight, d.removeChild(b), c && d.parentNode.removeChild(d), e) : !1
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    }), Modernizr.addTest("outputelem",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          "value"in document.createElement("output")), Modernizr.addTest("time",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         "valueAsDate"in document.createElement("time")), Modernizr.addTest("ruby",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                function g(a, b) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    var c;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    return window.getComputedStyle ? c = document.defaultView.getComputedStyle(a,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               null).getPropertyValue(b) : a.currentStyle && (c = a.currentStyle[b]), c
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                }

                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                function h() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    d.removeChild(a), a = null, b = null, c = null
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                }

                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                var a = document.createElement("ruby"), b = document.createElement("rt"), c = document.createElement("rp"), d = document.documentElement, e = "display", f = "fontSize";
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                return a.appendChild(c), a.appendChild(b), d.appendChild(a), g(c,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               e) == "none" || g(a,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 e) == "ruby" && g(b,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   e) == "ruby-text" || g(c,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          f) == "6pt" && g(b,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           f) == "6pt" ? (h(), !0) : (h(), !1)
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            }), Modernizr.addTest("progressbar",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      return document.createElement("progress").max !== undefined
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  }), Modernizr.addTest("meter",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            return document.createElement("meter").max !== undefined
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        }), Modernizr.addTest({texttrackapi : typeof document.createElement("video").addTextTrack == "function", track : "kind"in document.createElement("track")}), Modernizr.addTest("emoji",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           if(!Modernizr.canvastext) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               return!1;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           var a = document.createElement("canvas"), b = a.getContext("2d");
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           return b.textBaseline = "top", b.font = "32px Arial", b.fillText("😃",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            0,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            0), b.getImageData(16,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               16,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               1,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               1).data[0] !== 0
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       }), Modernizr.addTest("devicemotion",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             "DeviceMotionEvent"in window), Modernizr.addTest("deviceorientation",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              "DeviceOrientationEvent"in window), Modernizr.addTest("strictmode",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        return function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            return"use strict", !this
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        }()
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    }), function() {
    var a = new Image;
    a.onerror = function() {
        Modernizr.addTest("exif-orientation", function() {
            return!1
        })
    }, a.onload = function() {
        Modernizr.addTest("exif-orientation", function() {
            return a.width !== 2
        })
    }, a.src = "data:image/jpeg;base64,/9j/4AAQSkZJRgABAQEAYABgAAD/4QAiRXhpZgAASUkqAAgAAAABABIBAwABAAAABgASAAAAAAD/2wBDAAEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQH/2wBDAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQEBAQH/wAARCAABAAIDASIAAhEBAxEB/8QAHwAAAQUBAQEBAQEAAAAAAAAAAAECAwQFBgcICQoL/8QAtRAAAgEDAwIEAwUFBAQAAAF9AQIDAAQRBRIhMUEGE1FhByJxFDKBkaEII0KxwRVS0fAkM2JyggkKFhcYGRolJicoKSo0NTY3ODk6Q0RFRkdISUpTVFVWV1hZWmNkZWZnaGlqc3R1dnd4eXqDhIWGh4iJipKTlJWWl5iZmqKjpKWmp6ipqrKztLW2t7i5usLDxMXGx8jJytLT1NXW19jZ2uHi4+Tl5ufo6erx8vP09fb3+Pn6/8QAHwEAAwEBAQEBAQEBAQAAAAAAAAECAwQFBgcICQoL/8QAtREAAgECBAQDBAcFBAQAAQJ3AAECAxEEBSExBhJBUQdhcRMiMoEIFEKRobHBCSMzUvAVYnLRChYkNOEl8RcYGRomJygpKjU2Nzg5OkNERUZHSElKU1RVVldYWVpjZGVmZ2hpanN0dXZ3eHl6goOEhYaHiImKkpOUlZaXmJmaoqOkpaanqKmqsrO0tba3uLm6wsPExcbHyMnK0tPU1dbX2Nna4uPk5ebn6Onq8vP09fb3+Pn6/9oADAMBAAIRAxEAPwD+/iiiigD/2Q=="
}(), Modernizr.addTest("filereader", function() {
    return!!(window.File && window.FileList && window.FileReader)
}), Modernizr.addTest("formattribute", function() {
    var a = document.createElement("form"), b = document.createElement("input"), c = document.createElement("div"), d = "formtest" + (new Date).getTime(), e, f = !1;
    return a.id = d, document.createAttribute && (e = document.createAttribute("form"), e.nodeValue = d, b.setAttributeNode(e), c.appendChild(a), c.appendChild(b), document.documentElement.appendChild(c), f = a.elements.length === 1 && b.form == a, c.parentNode.removeChild(c)), f
}), Modernizr.addTest("filesystem", !!Modernizr.prefixed("requestFileSystem",
                                                         window)), Modernizr.addTest("placeholder",
                                                                                     function() {
                                                                                         return"placeholder"in(Modernizr.input || document.createElement("input")) && "placeholder"in(Modernizr.textarea || document.createElement("textarea"))
                                                                                     }), Modernizr.addTest("speechinput",
                                                                                                           function() {
                                                                                                               var a = document.createElement("input");
                                                                                                               return"speech"in a || "onwebkitspeechchange"in a
                                                                                                           }), function(a, b) {
    b.formvalidationapi = !1, b.formvalidationmessage = !1, b.addTest("formvalidation",
                                                                      function() {
                                                                          var c = a.createElement("form");
                                                                          if("checkValidity"in c) {
                                                                              var d = a.body, e = a.documentElement, f = !1, g = !1, h;
                                                                              return b.formvalidationapi = !0, c.onsubmit = function(a) {
                                                                                  window.opera || a.preventDefault(), a.stopPropagation()
                                                                              }, c.innerHTML = '<input name="modTest" required><button></button>', c.style.position = "absolute", c.style.top = "-99999em", d || (f = !0, d = a.createElement("body"), d.style.background = "", e.appendChild(d)), d.appendChild(c), h = c.getElementsByTagName("input")[0], h.oninvalid = function(a) {
                                                                                  g = !0, a.preventDefault(), a.stopPropagation()
                                                                              }, b.formvalidationmessage = !!h.validationMessage, c.getElementsByTagName("button")[0].click(), d.removeChild(c), f && e.removeChild(d), g
                                                                          }
                                                                          return!1
                                                                      })
}(document, window.Modernizr), Modernizr.addTest("fullscreen", function() {
    for(var a = 0; a < Modernizr._domPrefixes.length; a++
        ) {
        if(document[Modernizr._domPrefixes[a].toLowerCase() + "CancelFullScreen"]) {
            return!0;
        }
    }
    return!!document.cancelFullScreen || !1
}), Modernizr.addTest("gamepads", !!Modernizr.prefixed("getGamepads",
                                                       navigator)), Modernizr.addTest("getusermedia",
                                                                                      !!Modernizr.prefixed("getUserMedia",
                                                                                                           navigator)), Modernizr.addTest("ie8compat",
                                                                                                                                          function() {
                                                                                                                                              return!window.addEventListener && document.documentMode && document.documentMode === 7
                                                                                                                                          }), Modernizr.addTest("sandbox",
                                                                                                                                                                "sandbox"in document.createElement("iframe")), Modernizr.addTest("seamless",
                                                                                                                                                                                                                                 "seamless"in document.createElement("iframe")), function() {
    if(!Modernizr.canvas) {
        return!1;
    }
    var a = new Image, b = document.createElement("canvas"), c = b.getContext("2d");
    a.onload = function() {
        Modernizr.addTest("apng", function() {
            return typeof b.getContext == "undefined" ? !1 : (c.drawImage(a, 0,
                                                                          0), c.getImageData(0,
                                                                                             0,
                                                                                             1,
                                                                                             1).data[3] === 0)
        })
    }, a.src = "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAACGFjVEwAAAABAAAAAcMq2TYAAAANSURBVAiZY2BgYPgPAAEEAQB9ssjfAAAAGmZjVEwAAAAAAAAAAQAAAAEAAAAAAAAAAAD6A+gBAbNU+2sAAAARZmRBVAAAAAEImWNgYGBgAAAABQAB6MzFdgAAAABJRU5ErkJggg=="
}(), Modernizr.addTest("srcdoc",
                       "srcdoc"in document.createElement("iframe")), function() {
    var a = new Image;
    a.onerror = function() {
        Modernizr.addTest("webp", !1)
    }, a.onload = function() {
        Modernizr.addTest("webp", function() {
            return a.width == 1
        })
    }, a.src = "data:image/webp;base64,UklGRiwAAABXRUJQVlA4ICAAAAAUAgCdASoBAAEAL/3+/3+CAB/AAAFzrNsAAP5QAAAAAA=="
}(), Modernizr.addTest("json",
                       !!window.JSON && !!JSON.parse), Modernizr.addTest("olreversed",
                                                                         "reversed"in document.createElement("ol")), Modernizr.addTest("lowbandwidth",
                                                                                                                                       function() {
                                                                                                                                           var a = navigator.connection || {type : 0};
                                                                                                                                           return a.type == 3 || a.type == 4 || /^[23]g$/.test(a.type)
                                                                                                                                       }), Modernizr.addTest("eventsource",
                                                                                                                                                             !!window.EventSource), Modernizr.addTest("xhr2",
                                                                                                                                                                                                      "FormData"in window), Modernizr.addTest("notification",
                                                                                                                                                                                                                                              !!Modernizr.prefixed("Notifications",
                                                                                                                                                                                                                                                                   window)), Modernizr.addTest("performance",
                                                                                                                                                                                                                                                                                               !!Modernizr.prefixed("performance",
                                                                                                                                                                                                                                                                                                                    window)), Modernizr.addTest("pointerlock",
                                                                                                                                                                                                                                                                                                                                                !!Modernizr.prefixed("pointerLockElement",
                                                                                                                                                                                                                                                                                                                                                                     document)), Modernizr.addTest("raf",
                                                                                                                                                                                                                                                                                                                                                                                                   !!Modernizr.prefixed("requestAnimationFrame",
                                                                                                                                                                                                                                                                                                                                                                                                                        window)), Modernizr.addTest("quotamanagement",
                                                                                                                                                                                                                                                                                                                                                                                                                                                    function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                        var a = Modernizr.prefixed("StorageInfo",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   window);
                                                                                                                                                                                                                                                                                                                                                                                                                                                        return!!(a && "TEMPORARY"in a && "PERSISTENT"in a)
                                                                                                                                                                                                                                                                                                                                                                                                                                                    }), Modernizr.addTest("scriptasync",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                          "async"in document.createElement("script")), Modernizr.addTest("scriptdefer",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         "defer"in document.createElement("script")), Modernizr.addTest("stylescoped",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        "scoped"in document.createElement("style")), Modernizr.addTest("svgfilters",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           var a = !1;
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           try {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               a = typeof SVGFEColorMatrixElement !== undefined && SVGFEColorMatrixElement.SVG_FECOLORMATRIX_TYPE_SATURATE == 2
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           catch(b) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           }
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           return a
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       }), Modernizr.addTest("unicode",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             function() {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 var a, b = document.createElement("span"), c = document.createElement("span");
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 return Modernizr.testStyles("#modernizr{font-family:Arial,sans;font-size:300em;}",
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             function(d) {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 b.innerHTML = "&#5987", c.innerHTML = "&#9734", d.appendChild(b), d.appendChild(c), a = "offsetWidth"in b && b.offsetWidth !== c.offsetWidth
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             }), a
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             }), function() {
    var a = new Image;
    a.onerror = function() {
        Modernizr.addTest("datauri", function() {
            return!1
        })
    }, a.onload = function() {
        Modernizr.addTest("datauri", function() {
            return a.width == 1 && a.height == 1
        })
    }, a.src = "data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///ywAAAAAAQABAAACAUwAOw=="
}(), Modernizr.addTest("userdata", function() {
    return!!document.createElement("div").addBehavior
}), Modernizr.addTest("vibrate", !!Modernizr.prefixed("vibrate",
                                                      navigator)), Modernizr.addTest("webintents",
                                                                                     function() {
                                                                                         return!!Modernizr.prefixed("startActivity",
                                                                                                                    navigator)
                                                                                     }), function() {
    if(!Modernizr.webgl) {
        return;
    }
    var a, b, c;
    try {
        a = document.createElement("canvas"), b = a.getContext("webgl") || a.getContext("experimental-webgl"), c = b.getSupportedExtensions()
    }
    catch(d) {
        return
    }
    b === undefined ? Modernizr.webgl = new Boolean(!1) : Modernizr.webgl = new Boolean(!0);
    for(var e = -1, f = c.length; ++e < f;
        ) {
        Modernizr.webgl[c[e]] = !0;
    }
    window.TEST && TEST.audvid && TEST.audvid.push("webgl"), a = undefined
}(), Modernizr.addTest("framed", function() {
    return window.location != top.location
}), function() {
    try {
        var a = "Modernizr", b = new Worker("data:text/javascript;base64,dGhpcy5vbm1lc3NhZ2U9ZnVuY3Rpb24oZSl7cG9zdE1lc3NhZ2UoZS5kYXRhKX0=");
        b.onmessage = function(c) {
            b.terminate(), Modernizr.addTest("dataworkers",
                                             a === c.data), b = null
        }, b.onerror = function() {
            Modernizr.addTest("dataworkers", !1), b = null
        }, setTimeout(function() {
            Modernizr.addTest("dataworkers", !1)
        }, 200), b.postMessage(a)
    }
    catch(c) {
        Modernizr.addTest("dataworkers", !1)
    }
}(), function() {
    try {
        var a = window.MozBlobBuilder || window.WebKitBlobBuilder || window.MSBlobBuilder || window.OBlobBuilder || window.BlobBuilder, b = window.MozURL || window.webkitURL || window.MSURL || window.OURL || window.URL, c = "Modernizr", d = new a;
        d.append("this.onmessage=function(e){postMessage(e.data)}");
        var e = b.createObjectURL(d.getBlob()), f = new Worker(e);
        d = null, f.onmessage = function(a) {
            f.terminate(), b.revokeObjectURL(e), Modernizr.addTest("blobworkers",
                                                                   c === a.data), f = null
        }, f.onerror = function() {
            Modernizr.addTest("blobworkers", !1), f = null
        }, setTimeout(function() {
            Modernizr.addTest("blobworkers", !1)
        }, 200), f.postMessage(c)
    }
    catch(g) {
        Modernizr.addTest("blobworkers", !1)
    }
}(), Modernizr.addTest("sharedworkers", function() {
    return!!window.SharedWorker
});